<?php
/**
 * Dynamic CSS
 *
 * The theme dynamic css class.
 *
 * @package Theme Vision
 * @subpackage Fury
 * @since 1.0.0
 * @since 1.2.80 Updated the code.
 */

namespace Fury;

// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Dynamic_CSS {
    
    /**
     * Instance
     *
     * Single instance of this object.
     *
     * @since 1.2.80
     * @access public
     * @return null|object
     */
    public static $instance = null;
    
    /**
     * Get Instance
     *
     * Access the single instance of this class.
     *
     * @since 1.2.80
     * @access public
     * @return object
     */
    public static function get_instance() {
        if ( null === self::$instance ) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    /**
     * Class Constructor
     */
    function __construct() {
        
        add_action( 'wp_head', array( $this, 'render' ) );
        
    }
    
    /**
     * Header Top Bar
     *
     * The header top bar background colors.
     *
     * @since 1.3.7
     * @access private
     * @return mixed
     */
    private function header_top_bar() {
        if( get_theme_mod( 'fury_htb_styling', true ) && 
            get_theme_mod( 'fury_htb_bg_color_switch', 'gradient-color') == 'gradient-color' ) {
            $start  = esc_attr( get_theme_mod( 'fury_htb_gradient_start_color', '#5540d9' ) );
            $end    = esc_attr( get_theme_mod( 'fury_htb_gradient_end_color', '#ee2762' ) );
            $angle  = esc_attr( get_theme_mod( 'fury_htb_gradient_angle', '90' ) );
            $css  = '.topbar {';
                $css .= 'background-color:'. $start .';';
                $css .= 'background-image:linear-gradient('. $angle .'deg, '. $start .' 0%, '. $end .' 100%)';
            $css .= '}';
            
            echo $css;
        }
    }
    
    /**
     * Header
     *
     * The header background colors.
     *
     * @since 1.3.7
     * @access private
     * @return mixed
     */
    private function header() {
        if( get_theme_mod( 'fury_header_styling', false ) && 
            get_theme_mod( 'fury_header_bg_color_switch', 'gradient-color') == 'gradient-color' ) {
            $start  = esc_attr( get_theme_mod( 'fury_header_gradient_start_color', '#5540d9' ) );
            $end    = esc_attr( get_theme_mod( 'fury_header_gradient_end_color', '#ee2762' ) );
            $angle  = esc_attr( get_theme_mod( 'fury_header_gradient_angle', '90' ) );
            $css  = 'header.navbar, header.navbar .site-search {';
                $css .= 'background-color:'. $start .';';
                $css .= 'background-image:linear-gradient('. $angle .'deg, '. $start .' 0%, '. $end .' 100%)';
            $css .= '}';
            $css .= 'header.navbar .site-search > input {';
                $css .= 'background-color:transparent;';
            $css .= '}';
            
            echo $css;
        }
    }
    
    /**
     * Render
     *
     * Render the CSS style inline.
     *
     * @since 1.0.0
     * @access public
     * @return mixed
     */
    public function render() { ?>
    <style type="text/css" id="fury-customize-css">
        
        <?php if( is_admin_bar_showing() ): ?>
        header.navbar-sticky.navbar-stuck { top: 32px; }
        .offcanvas-header { margin-top: 32px; }
        <?php endif; ?>
        
        <?php $this->header_top_bar(); ?>
        <?php $this->header(); ?>
        
    </style>
    <?php
    }
    
}

Dynamic_CSS::get_instance();

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
