<?php
/**
 * Initialize
 *
 * Initialize a Fury theme template files.
 *
 * @package Theme Vision
 * @subpackage Fury
 * @since 1.0.0
 */

namespace Fury;

// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Initialize {
    
    /**
     * Instance
     *
     * Single instance of this object.
     *
     * @since 1.0.0
     * @access public
     * @var null|object
     */
    public static $instance = null;
    
    /**
     * Get Instance
     *
     * Access the single instance of this class.
     *
     * @since 1.0.0
     * @access public
     * @return object
     */
    public static function get_instance() {
        if ( null === self::$instance ) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    /**
     * Class Constructor
     */
    function __construct() {
        
        if ( ! defined( 'ELEMENTOR_PARTNER_ID' ) ) {
            define( 'ELEMENTOR_PARTNER_ID', 2132 );
        }
        
        if( ! defined( 'MONSTERINSIGHTS_SHAREASALE_ID' ) ) {
            define( 'MONSTERINSIGHTS_SHAREASALE_ID', 69975 );
        }
        
        $this->get_template_files();
    }
    
    /**
     * Get Template Files
     *
     * Include all Fury template files.
     *
     * @since 1.0.0
     * @access private
     * @return void
     */
    private function get_template_files() {
        if( has_action( 'fury/before_files_loaded' ) ) {
            /**
             * Hook: fury/before_files_loaded
             *
             * @hooked none
             *
             * @since 1.2.80
             */
            do_action( 'fury/before_files_loaded' );
        }
        
        if( is_admin() ) {
            get_template_part( 'framework/fury-plugin-activation' );
        }
        
        get_template_part( 'framework/classes/class-fury-helper' );
        get_template_part( 'framework/classes/class-fury-setup' );
        get_template_part( 'framework/classes/class-fury-theme' );
        get_template_part( 'framework/admin/fury-customizer' );
        get_template_part( 'framework/classes/class-fury-widgets' );
        get_template_part( 'framework/classes/class-fury-woocommerce' );
        get_template_part( 'framework/classes/class-fury-slider' );
        get_template_part( 'framework/fury-functions' );
        get_template_part( 'framework/fury-actions' );
        get_template_part( 'framework/fury-filters' );
        
        if( has_action( 'fury/after_files_loaded' ) ) {
            /**
             * Hook: fury/after_files_loaded
             *
             * @hooked none
             *
             * @since 1.2.80
             */
            do_action( 'fury/after_files_loaded' );
        }
    }
    
}

Initialize::get_instance();

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
